@@ -79,7 +79,7 @@ class rc_html2text extends PHPUnit\Framework\TestCase
      */
     function test_html2text($title, $in, $out)
     {
-        $ht = new rcube_html2text(null, false, false);
+        $ht = new rcube_html2text(null, false, rcube_html2text::LINKS_NONE);
 
         $ht->set_html($in);
         $res = $ht->get_text();
@@ -98,12 +98,12 @@ class rc_html2text extends PHPUnit\Framework\TestCase
 <div><br></div><div>Par 3</div><div><br></div>
 <blockquote>INNER 3</blockquote>OUTER END</blockquote>
 EOF;
-        $ht = new rcube_html2text($html, false, false);
+        $ht = new rcube_html2text($html, false, rcube_html2text::LINKS_NONE);
         $res = $ht->get_text();
 
-        $this->assertContains('>> INNER 1', $res, 'Quote inner');
-        $this->assertContains('>> INNER 3', $res, 'Quote inner');
-        $this->assertContains('> OUTER END', $res, 'Quote outer');
+        $this->assertStringContainsString('>> INNER 1', $res, 'Quote inner');
+        $this->assertStringContainsString('>> INNER 3', $res, 'Quote inner');
+        $this->assertStringContainsString('> OUTER END', $res, 'Quote outer');
     }
 
     function test_broken_blockquotes()
@@ -115,10 +115,10 @@ Begin<br>
 <blockquote>
 NO END TAG FOUND
 EOF;
-        $ht = new rcube_html2text($html, false, false);
+        $ht = new rcube_html2text($html, false, rcube_html2text::LINKS_NONE);
         $res = $ht->get_text();
 
-        $this->assertContains('QUOTED TEXT NO END TAG FOUND', $res, 'No quoting on invalid html');
+        $this->assertStringContainsString('QUOTED TEXT NO END TAG FOUND', $res, 'No quoting on invalid html');
 
         // with some (nested) end tags
         $html = <<<EOF
@@ -128,10 +128,10 @@ Begin<br>
 <blockquote>INNER 2</blockquote>
 NO END TAG FOUND
 EOF;
-        $ht = new rcube_html2text($html, false, false);
+        $ht = new rcube_html2text($html, false, rcube_html2text::LINKS_NONE);
         $res = $ht->get_text();
 
-        $this->assertContains('QUOTED TEXT INNER 1 INNER 2 NO END', $res, 'No quoting on invalid html');
+        $this->assertStringContainsString('QUOTED TEXT INNER 1 INNER 2 NO END', $res, 'No quoting on invalid html');
     }
 
     /**
@@ -142,6 +142,34 @@ EOF;
         $html     = '<a href="http://test.com">content</a>';
         $expected = 'content [1]
 
+Links:
+------
+[1] http://test.com
+';
+
+        $ht = new rcube_html2text($html, false, rcube_html2text::LINKS_END);
+        $res = $ht->get_text();
+
+        $this->assertSame($expected, $res, 'Links list');
+
+        // href == content (#1490434)
+        $html     = '<a href="http://test.com">http://test.com</a>';
+        $expected = 'http://test.com';
+
+        $ht = new rcube_html2text($html, false, rcube_html2text::LINKS_END);
+        $res = $ht->get_text();
+
+        $this->assertSame($expected, $res, 'Skip link with href == content');
+    }
+
+    /**
+     * Test links handling with backward compatibility boolean flag
+     */
+    function test_links_bc_with_boolean()
+    {
+        $html     = '<a href="http://test.com">content</a>';
+        $expected = 'content [1]
+
 Links:
 ------
 [1] http://test.com
@@ -162,12 +190,48 @@ Links:
         $this->assertSame($expected, $res, 'Skip link with href == content');
     }
 
+    /**
+     * Test links inline handling
+     */
+    function test_links_inline()
+    {
+        $html     = '<a href="http://test.com">content</a>';
+        $expected = 'content <http://test.com>';
+
+        $ht = new rcube_html2text($html, false, rcube_html2text::LINKS_INLINE);
+        $res = $ht->get_text();
+
+        $this->assertSame($expected, $res, 'Links Inline');
+
+        // href == content (#1490434)
+        $html     = '<a href="http://test.com">http://test.com</a>';
+        $expected = 'http://test.com';
+
+        $ht = new rcube_html2text($html, false, rcube_html2text::LINKS_INLINE);
+        $res = $ht->get_text();
+
+        $this->assertSame($expected, $res, 'Skip link with href == content');
+    }
+
     /**
      * Test <a> links handling when not using link list (#5795)
      *
      * @dataProvider data_links_no_list
      */
     function test_links_no_list($input, $output)
+    {
+        $h2t = new rcube_html2text($input, false, rcube_html2text::LINKS_NONE);
+        $res = $h2t->get_text();
+
+        $this->assertSame($output, $res, 'Links handling');
+    }
+
+    /**
+     * Test <a> links handling when not using link list (#5795) with backward compatibility boolean flag
+     *
+     * @dataProvider data_links_no_list
+     */
+    function test_links_no_list_bc_with_boolean($input, $output)
     {
         $h2t = new rcube_html2text($input, false, false);
         $res = $h2t->get_text();
@@ -197,6 +261,35 @@ Links:
         ];
     }
 
+    /**
+     * Test links fallback to default handling
+     */
+    function test_links_fallback_to_default_link_list()
+    {
+        $html     = '<a href="http://test.com">content</a>';
+        $expected = 'content [1]
+
+Links:
+------
+[1] http://test.com
+';
+
+        $ht = new rcube_html2text($html, false);
+        $res = $ht->get_text();
+
+        $this->assertSame($expected, $res, 'Links list as default (doLinks not set)');
+
+        $ht = new rcube_html2text($html, false, mt_rand(3, 9999));
+        $res = $ht->get_text();
+
+        $this->assertSame($expected, $res, 'Links list as default (doLinks greater than 3)');
+
+        $ht = new rcube_html2text($html, false, mt_rand(-9999, -1));
+        $res = $ht->get_text();
+
+        $this->assertSame($expected, $res, 'Links list as default (doLinks lower than 0)');
+    }
+
     /**
      * Test huge HTML content (#8137)
      */
@@ -206,7 +299,7 @@ Links:
         $src = 'data:image/png;base64,' . str_repeat('1234567890abcdefghijklmnopqrstuvwxyz', 50000);
         $input = 'test<body><p>test1</p><p>test2</p><img src="' . $src . '" /><p>test3</p>';
 
-        $h2t = new rcube_html2text($input, false, false);
+        $h2t = new rcube_html2text($input, false, rcube_html2text::LINKS_NONE);
         $res = $h2t->get_text();
 
         $this->assertSame("test1\n\ntest2\n\ntest3", $res, 'Huge input');
