@@ -41,13 +41,13 @@ class Framework_VCard extends PHPUnit\Framework\TestCase
         $vcard = new rcube_vcard(file_get_contents($this->_srcpath('johndoe.vcf')), null);
 
         $vcf = $vcard->export();
-        $this->assertRegExp('/TEL;CELL:\+987654321/', $vcf, "Return CELL instead of MOBILE (import)");
+        $this->assertMatchesRegularExpression('/TEL;CELL:\+987654321/', $vcf, "Return CELL instead of MOBILE (import)");
 
         $vcard = new rcube_vcard();
         $vcard->set('phone', '+987654321', 'MOBILE');
 
         $vcf = $vcard->export();
-        $this->assertRegExp('/TEL;TYPE=CELL:\+987654321/', $vcf, "Return CELL instead of MOBILE (set)");
+        $this->assertMatchesRegularExpression('/TEL;TYPE=CELL:\+987654321/', $vcf, "Return CELL instead of MOBILE (set)");
     }
 
     /**
@@ -111,7 +111,7 @@ class Framework_VCard extends PHPUnit\Framework\TestCase
 
         // https://github.com/roundcube/roundcubemail/issues/1934
         $vcards2 = rcube_vcard::import(file_get_contents($this->_srcpath('thebat.vcf')));
-        $this->assertEquals("Iksiñski", $vcards2[0]->surname, "Detect charset in encoded values");
+        $this->assertEquals("Iksi=F1ski", quoted_printable_encode($vcards2[0]->surname));
 
         $vcards[0]->reset();
         // TODO: Test reset() method
@@ -122,10 +122,11 @@ class Framework_VCard extends PHPUnit\Framework\TestCase
         $input = file_get_contents($this->_srcpath('photo.vcf'));
 
         $vcards = rcube_vcard::import($input);
-        $vcard = $vcards[0]->get_assoc();
 
         $this->assertCount(1, $vcards, "Detected 1 vcard");
 
+        $vcard = $vcards[0]->get_assoc();
+
         // ENCODING=b case (#1488683)
         $this->assertEquals("/9j/4AAQSkZJRgABAQA", substr(base64_encode($vcard['photo']), 0, 19), "Photo decoding");
         $this->assertEquals("Müller", $vcard['surname'], "Unicode characters");
