@@ -30,9 +30,9 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertNotRegExp('/data:text/', $washed, "Remove data:text/html links");
-        $this->assertNotRegExp('/vbscript:/', $washed, "Remove vbscript: links");
-        $this->assertNotRegExp('/data:application/', $washed, "Remove data:application links");
+        $this->assertDoesNotMatchRegularExpression('/data:text/', $washed, "Remove data:text/html links");
+        $this->assertDoesNotMatchRegularExpression('/vbscript:/', $washed, "Remove vbscript: links");
+        $this->assertDoesNotMatchRegularExpression('/data:application/', $washed, "Remove data:application links");
     }
 
     /**
@@ -45,8 +45,8 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertRegExp('|href="http://test\.com"|', $washed, "Link href with newlines (#1488940)");
-        $this->assertRegExp('|href="http://domain\.com"|', $washed, "Link href with no protocol (#7454)");
+        $this->assertMatchesRegularExpression('|href="http://test\.com"|', $washed, "Link href with newlines (#1488940)");
+        $this->assertMatchesRegularExpression('|href="http://domain\.com"|', $washed, "Link href with no protocol (#7454)");
     }
 
     /**
@@ -64,9 +64,9 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertNotRegExp('/data:text/', $washed, "data:text/html in area href");
-        $this->assertNotRegExp('/vbscript:/', $washed, "vbscript: in area href");
-        $this->assertNotRegExp('/javascript:/', $washed, "javascript: in area href");
+        $this->assertDoesNotMatchRegularExpression('/data:text/', $washed, "data:text/html in area href");
+        $this->assertDoesNotMatchRegularExpression('/vbscript:/', $washed, "vbscript: in area href");
+        $this->assertDoesNotMatchRegularExpression('/javascript:/', $washed, "javascript: in area href");
     }
 
     /**
@@ -81,9 +81,9 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertNotRegExp('/<\/?object/', $washed, "Remove object tag");
-        $this->assertNotRegExp('/<param/', $washed, "Remove param tag");
-        $this->assertRegExp('/<p>/', $washed, "Keep embedded tags");
+        $this->assertDoesNotMatchRegularExpression('/<\/?object/', $washed, "Remove object tag");
+        $this->assertDoesNotMatchRegularExpression('/<param/', $washed, "Remove param tag");
+        $this->assertMatchesRegularExpression('/<p>/', $washed, "Keep embedded tags");
     }
 
     /**
@@ -134,7 +134,7 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertRegExp('|<textarea>test</textarea>|', $washed, "Self-closing textarea (#1489137)");
+        $this->assertMatchesRegularExpression('|<textarea>test</textarea>|', $washed);
     }
 
     /**
@@ -147,7 +147,7 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertRegExp('|</a>|', $washed, "Invalid closing tag (#1489446)");
+        $this->assertMatchesRegularExpression('|</a>|', $washed);
     }
 
     /**
@@ -203,8 +203,8 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertRegExp('|color: rgb\(241, 245, 218\)|', $washed, "Color style (#1489697)");
-        $this->assertRegExp('|font-size: 10px|', $washed, "Font-size style");
+        $this->assertMatchesRegularExpression('|color: rgb\(241, 245, 218\)|', $washed, "Color style (#1489697)");
+        $this->assertMatchesRegularExpression('|font-size: 10px|', $washed, "Font-size style");
     }
 
     /**
@@ -218,7 +218,11 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertRegExp('|style="font-family: \&quot;新細明體\&quot;,\&quot;serif\&quot;; color: red"|', $washed, "Unicode chars in style attribute - quoted (#1489697)");
+        $this->assertMatchesRegularExpression(
+            '|style="font-family: \&quot;新細明體\&quot;,\&quot;serif\&quot;; color: red"|',
+            $washed,
+            "Unicode chars in style attribute - quoted (#1489697)"
+        );
 
         $html = "<html><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />
             <body><span style='font-family:新細明體;color:red'>test</span></body></html>";
@@ -226,7 +230,11 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertRegExp('|style="font-family: 新細明體; color: red"|', $washed, "Unicode chars in style attribute (#1489697)");
+        $this->assertMatchesRegularExpression(
+            '|style="font-family: 新細明體; color: red"|',
+            $washed,
+            "Unicode chars in style attribute (#1489697)"
+        );
     }
 
     /**
@@ -241,12 +249,12 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml(['html_elements' => ['body']]);
         $washed = $washer->wash($html);
 
-        $this->assertRegExp('|bgcolor="#fff"|', $washed, "Body bgcolor attribute");
-        $this->assertRegExp('|text="#000"|', $washed, "Body text attribute");
-        $this->assertRegExp('|background="#test"|', $washed, "Body background attribute");
-        $this->assertRegExp('|link="#111"|', $washed, "Body link attribute");
-        $this->assertRegExp('|alink="#222"|', $washed, "Body alink attribute");
-        $this->assertRegExp('|vlink="#333"|', $washed, "Body vlink attribute");
+        $this->assertMatchesRegularExpression('|bgcolor="#fff"|', $washed, "Body bgcolor attribute");
+        $this->assertMatchesRegularExpression('|text="#000"|', $washed, "Body text attribute");
+        $this->assertMatchesRegularExpression('|background="#test"|', $washed, "Body background attribute");
+        $this->assertMatchesRegularExpression('|link="#111"|', $washed, "Body link attribute");
+        $this->assertMatchesRegularExpression('|alink="#222"|', $washed, "Body alink attribute");
+        $this->assertMatchesRegularExpression('|vlink="#333"|', $washed, "Body vlink attribute");
     }
 
     /**
@@ -259,8 +267,8 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertRegExp('|line-height: 1;|', $washed, "Untouched line-height (#1489917)");
-        $this->assertRegExp('|; height: 10px|', $washed, "Fixed height units");
+        $this->assertMatchesRegularExpression('|line-height: 1;|', $washed, "Untouched line-height (#1489917)");
+        $this->assertMatchesRegularExpression('|; height: 10px|', $washed, "Fixed height units");
 
         $html     = "<div style=\"padding: 0px\n   20px;border:1px solid #000;\"></div>";
         $expected = "<div style=\"padding: 0px 20px; border: 1px solid #000\"></div>";
@@ -293,6 +301,24 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $this->assertTrue(strpos($washed, $exp) !== false, "Style quotes XSS issue (#1490227)");
     }
 
+    /**
+     * Test handling of title tag
+     */
+    function test_title()
+    {
+        $washer = new rcube_washtml;
+
+        $html = "<html><head><title>title1</title></head><body><p>test</p></body>";
+        $washed = $washer->wash($html);
+
+        $this->assertSame('<p>test</p>', $this->cleanupResult($washed));
+
+        $html = "<html><head><title>title1<img />title2</title></head><body><p>test</p></body>";
+        $washed = $washer->wash($html);
+
+        $this->assertSame('<p>test</p>', $this->cleanupResult($washed));
+    }
+
     /**
      * Test SVG cleanup
      */
@@ -342,11 +368,11 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         return [
             [
                 '<head xmlns="&quot;&gt;&lt;script&gt;alert(document.domain)&lt;/script&gt;"><svg></svg></head>',
-                '<svg xmlns="http://www.w3.org/1999/xhtml"></svg>'
+                '<svg></svg>'
             ],
             [
                 '<head xmlns="&quot; onload=&quot;alert(document.domain)">Hello victim!<svg></svg></head>',
-                'Hello victim!<svg xmlns="http://www.w3.org/1999/xhtml"></svg>'
+                'Hello victim!<svg></svg>'
             ],
             [
                 '<p>Hello victim!<svg xmlns="&quot; onload=&quot;alert(document.domain)"></svg></p>',
@@ -354,7 +380,7 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
             ],
             [
                 '<html><p>Hello victim!<svg xmlns="&quot; onload=&quot;alert(document.domain)"></svg></p>',
-                '<p>Hello victim!<svg xmlns="http://www.w3.org/1999/xhtml"></svg></p>'
+                '<p>Hello victim!<svg></svg></p>'
             ],
             [
                 '<svg xmlns="&quot; onload=&quot;alert(document.domain)" />',
@@ -362,7 +388,7 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
             ],
             [
                 '<html><svg xmlns="&quot; onload=&quot;alert(document.domain)" />',
-                '<svg xmlns="http://www.w3.org/1999/xhtml"></svg>'
+                '<svg></svg>'
             ],
             [
                 '<svg><a xlink:href="javascript:alert(1)"><text x="20" y="20">XSS</text></a></svg>',
@@ -370,7 +396,7 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
             ],
             [
                 '<html><svg><a xlink:href="javascript:alert(1)"><text x="20" y="20">XSS</text></a></svg>',
-                '<svg xmlns="http://www.w3.org/1999/xhtml"><a x-washed="xlink:href"><text x="20" y="20">XSS</text></a></svg>'
+                '<svg><a x-washed="xlink:href"><text x="20" y="20">XSS</text></a></svg>'
             ],
             [
                 '<svg><animate xlink:href="#xss" attributeName="href" values="javascript:alert(1)" />'
@@ -380,8 +406,7 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
             [
                 '<html><svg><animate xlink:href="#xss" attributeName="href" values="javascript:alert(1)" />'
                     . '<a id="xss"><text x="20" y="20">XSS</text></a></svg>',
-                '<svg xmlns="http://www.w3.org/1999/xhtml">'
-                    . '<!-- animate blocked --><a id="xss"><text x="20" y="20">XSS</text></a></svg>',
+                '<svg><!-- animate blocked --><a id="xss"><text x="20" y="20">XSS</text></a></svg>',
             ],
             [
                 '<svg><animate xlink:href="#xss" attributeName="href" from="javascript:alert(1)" to="1" />'
@@ -463,6 +488,10 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
                 '<html><body background="javascript:alert(1)">',
                 '<body x-washed="background"></body>'
             ],
+            [
+                '<html><body><img fill=\'asd:url(#asd)" src="x" onerror="alert(1)\' />',
+                '<body><img fill="asd:url(#asd)&quot; src=&quot;x&quot; onerror=&quot;alert(1)" /></body>'
+            ],
             [
                 '<html><math href="javascript:alert(location);"><mi>clickme</mi></math>',
                 '<body><math x-washed="href"><mi>clickme</mi></math></body>',
@@ -568,7 +597,7 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washed = $washer->wash($html);
 
         $this->assertTrue($washer->extlinks);
-        $this->assertNotContains('TRACKING', $washed, "Src attribute of <input> tag (#5583)");
+        $this->assertStringNotContainsString('TRACKING', $washed, "Src attribute of <input> tag (#5583)");
 
         $html = "<video src=\"http://TRACKING_URL/\">";
 
@@ -576,7 +605,7 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washed = $washer->wash($html);
 
         $this->assertTrue($washer->extlinks);
-        $this->assertNotContains('TRACKING', $washed, "Src attribute of <video> tag (#5583)");
+        $this->assertStringNotContainsString('TRACKING', $washed, "Src attribute of <video> tag (#5583)");
     }
 
     /**
@@ -614,8 +643,8 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $washer = new rcube_washtml;
         $washed = $washer->wash($html);
 
-        $this->assertNotContains('onerror=alert(1)>', $washed);
-        $this->assertContains('&lt;p style=&quot;x:', $washed);
+        $this->assertStringNotContainsString('onerror=alert(1)>', $washed);
+        $this->assertStringContainsString('&lt;p style=&quot;x:', $washed);
     }
 
     /**
@@ -631,10 +660,10 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
             . '</p>';
         $washed = $washer->wash($html);
 
-        $this->assertContains('id="testmy-id"', $washed);
-        $this->assertContains('for="testmy-other-id"', $washed);
-        $this->assertContains('href="#testmy-id"', $washed);
-        $this->assertContains('class="testmy-class1 testmy-class2"', $washed);
+        $this->assertStringContainsString('id="testmy-id"', $washed);
+        $this->assertStringContainsString('for="testmy-other-id"', $washed);
+        $this->assertStringContainsString('href="#testmy-id"', $washed);
+        $this->assertStringContainsString('class="testmy-class1 testmy-class2"', $washed);
     }
 
     /**
@@ -667,34 +696,34 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $html   = '<head></head>First line<br />Second line';
         $washed = $washer->wash($html);
 
-        $this->assertContains('First line', $washed);
+        $this->assertStringContainsString('First line', $washed);
 
         $html   = 'First line<br />Second line';
         $washed = $washer->wash($html);
 
-        $this->assertContains('First line', $washed);
+        $this->assertStringContainsString('First line', $washed);
 
         $html   = '<html>First line<br />Second line</html>';
         $washed = $washer->wash($html);
 
-        $this->assertContains('>First line', $washed);
+        $this->assertStringContainsString('>First line', $washed);
 
         $html   = '<html><head></head>First line<br />Second line</html>';
         $washed = $washer->wash($html);
 
-        $this->assertContains('First line', $washed);
+        $this->assertStringContainsString('First line', $washed);
 
         // Not really valid HTML, but because its common in email world
         // and because it works with DOMDocument, we make sure its supported
         $html   = 'First line<br /><html><body>Second line';
         $washed = $washer->wash($html);
 
-        $this->assertContains('First line', $washed);
+        $this->assertStringContainsString('First line', $washed);
 
         $html   = 'First line<br /><html>Second line';
         $washed = $washer->wash($html);
 
-        $this->assertContains('First line', $washed);
+        $this->assertStringContainsString('First line', $washed);
     }
 
     /**
@@ -718,13 +747,13 @@ class Framework_Washtml extends PHPUnit\Framework\TestCase
         $html = file_get_contents(TESTS_DIR . 'src/htmlbase.txt');
         $html = rcube_washtml::resolve_base($html);
 
-        $this->assertRegExp('|src="http://alec\.pl/dir/img1\.gif"|', $html, "URI base resolving [1]");
-        $this->assertRegExp('|src="http://alec\.pl/dir/img2\.gif"|', $html, "URI base resolving [2]");
-        $this->assertRegExp('|src="http://alec\.pl/img3\.gif"|', $html, "URI base resolving [3]");
+        $this->assertMatchesRegularExpression('|src="http://alec\.pl/dir/img1\.gif"|', $html, "URI base resolving [1]");
+        $this->assertMatchesRegularExpression('|src="http://alec\.pl/dir/img2\.gif"|', $html, "URI base resolving [2]");
+        $this->assertMatchesRegularExpression('|src="http://alec\.pl/img3\.gif"|', $html, "URI base resolving [3]");
 
         // base resolving exceptions
-        $this->assertRegExp('|src="cid:theCID"|', $html, "URI base resolving exception [1]");
-        $this->assertRegExp('|src="http://other\.domain\.tld/img3\.gif"|', $html, "URI base resolving exception [2]");
+        $this->assertMatchesRegularExpression('|src="cid:theCID"|', $html, "URI base resolving exception [1]");
+        $this->assertMatchesRegularExpression('|src="http://other\.domain\.tld/img3\.gif"|', $html, "URI base resolving exception [2]");
     }
 
     /**
