@@ -12,7 +12,18 @@ class Rcmail_RcmailSendmail extends ActionTestCase
      */
     function test_headers_input()
     {
-        $this->markTestIncomplete();
+        $_POST = [
+            '_subject' => "Test1\nTest2",
+            '_from' => 'Sender <test@domain.tld>',
+        ];
+
+        $sendmail = new rcmail_sendmail();
+        $headers = $sendmail->headers_input();
+
+        $this->assertSame('Test1 Test2', $headers['Subject']);
+        $this->assertSame('Sender <test@domain.tld>', $headers['From']);
+        $this->assertSame('undisclosed-recipients:;', $headers['To']);
+        $this->assertSame('test@domain.tld', $headers['X-Sender']);
     }
 
     /**
@@ -114,6 +125,11 @@ class Rcmail_RcmailSendmail extends ActionTestCase
                 'test@domain.tld',
                 'UTF-8'
             ],
+            [
+                'test@domain.tld.', // #7899
+                'test@domain.tld',
+                'UTF-8'
+            ],
             [
                 'ö <t@test.com>',
                 'ö <t@test.com>',
@@ -124,6 +140,11 @@ class Rcmail_RcmailSendmail extends ActionTestCase
                 '=?ISO-2022-JP?B?GyRCLWo7M3l1OSk2SBsoQg==?= <t@domain.jp>',
                 'ISO-2022-JP'
             ],
+            [
+                'test@тест.рф.', // #8493
+                'test@xn--e1aybc.xn--p1ai',
+                'UTF-8',
+            ],
         ];
     }
 
